@@ -4,7 +4,8 @@ from encoders.base_encoder import BaseEncoder
 
 class BertEmbeddedAdapter(BaseEncoder):
 
-    def __init__(self, encoder: "BERTFeatureExtractor", input_dim: int, output_dim: int) -> None:
+    def __init__(self, encoder: "BERTFeatureExtractor", input_dim: int, output_dim: int, verbose=False) -> None:
+        super().__init__(verbose)
         self.__encoder = encoder
         self.__input_dim = input_dim
         self.__output_dim = output_dim
@@ -16,7 +17,7 @@ class BertEmbeddedAdapter(BaseEncoder):
         return self.__output_dim
 
     def encode(self, data: Iterable[Any]) -> Iterable[Any]:
-        return self.__encoder(data)
+        return self.__encoder(data, verbose=self._verbose)
 
 
 
