@@ -1,4 +1,4 @@
-
+ENCODER_VERBOSE = "verbose"
 PATH_DESC = "path_desc"
 
 ENCODER_PARAMS = "params"
@@ -39,3 +39,4 @@ ENCODER_TYPE_BERT_EMBEDDED = "bert_embedded"
 
 BERT_EMBEDDED_GRAPH = "graph"
 BERT_EMBEDDED_VOCAB = "vocab"
+BERT_EMBEDDED_MAX_SEQ_LEN = "seq_len"
